@@ -2,9 +2,10 @@ import logging
 import re
 from pathlib import Path
 from os.path import expanduser
+from typing import List
 
 from venv_management.driver import Driver
-from venv_management.errors import CommandNotFound, ImplementationNotFound
+from venv_management.errors import CommandNotFound, ImplementationNotFound, PythonNotFound
 from venv_management.utilities import sub_shell_command, get_status_output, parse_package_arg
 
 logger = logging.getLogger(__name__)
@@ -13,6 +14,9 @@ logger = logging.getLogger(__name__)
 DESTINATION_PATTERN = r"dest=([^,]+)"
 DESTINATION_REGEX = re.compile(DESTINATION_PATTERN)
 
+NO_SUCH_PYTHON_PATTERN = r"failed to find interpreter for Builtin discover of python_spec='([^']*)'"
+NO_SUCH_PYTHON_REGEX = re.compile(NO_SUCH_PYTHON_PATTERN)
+
 class VirtualEnvShDriver(Driver):
 
     def _check_availability(self):
@@ -22,7 +26,7 @@ class VirtualEnvShDriver(Driver):
             raise ImplementationNotFound(f"No implementation for {self.name}")
 
 
-    def list_virtual_envs(self) -> list[str]:
+    def list_virtual_envs(self) -> List[str]:
         """A list of virtualenv names.
 
         Returns:
@@ -90,7 +94,8 @@ class VirtualEnvShDriver(Driver):
             The Path to the root of the virtualenv, or None if the path could not be determined.
 
         Raises:
-            CommandNotFound: If the the required command could not be found.
+            PythonNotFound: If the requested Python version could not be found.
+            CommandNotFound: If the required command could not be found.
             RuntimeError: If the virtualenv could not be created.
         """
         project_path_arg = f"-a {project_path}" if project_path else ""
@@ -122,6 +127,9 @@ class VirtualEnvShDriver(Driver):
         status, output = get_status_output(command)
         if status == 127:
             raise CommandNotFound(output)
+        m = NO_SUCH_PYTHON_REGEX.search(output)
+        if m is not None:
+            raise PythonNotFound(f"Could not locate Python {python} ; {m.group(0)}")
         if status != 0:
             raise RuntimeError(f"Could not run {command}")
         lines = output.splitlines(keepends=False)
