@@ -4,9 +4,10 @@ import subprocess
 import sys
 from os.path import expanduser
 from pathlib import Path
+from typing import List
 
 from venv_management.driver import Driver
-from venv_management.errors import CommandNotFound, ImplementationNotFound
+from venv_management.errors import CommandNotFound, ImplementationNotFound, PythonNotFound
 from venv_management.utilities import sub_shell_command, get_status_output, shell_is_interactive, \
     remove_interactive_shell_warnings, parse_package_arg
 
@@ -15,6 +16,8 @@ logger = logging.getLogger(__name__)
 DESTINATION_PATTERN = r"dest=([^,]+)"
 DESTINATION_REGEX = re.compile(DESTINATION_PATTERN)
 
+NO_SUCH_PYTHON_PATTERN = r"failed to find interpreter for Builtin discover of python_spec='([^']*)'"
+NO_SUCH_PYTHON_REGEX = re.compile(NO_SUCH_PYTHON_PATTERN)
 
 class VirtualEnvWrapperDriver(Driver):
 
@@ -26,7 +29,7 @@ class VirtualEnvWrapperDriver(Driver):
             raise ImplementationNotFound(f"No implementation for {self.name}")
 
 
-    def list_virtual_envs(self) -> list[str]:
+    def list_virtual_envs(self) -> List[str]:
         """A list of virtualenv names.
 
         Returns:
@@ -95,6 +98,7 @@ class VirtualEnvWrapperDriver(Driver):
             The Path to the root of the virtualenv, or None if the path could not be determined.
 
         Raises:
+            PythonNotFound: If the requested Python version could not be found.
             RuntimeError: If the virtualenv could not be created.
         """
         project_path_arg = f"-a {project_path}" if project_path else ""
@@ -127,6 +131,9 @@ class VirtualEnvWrapperDriver(Driver):
         status, output = get_status_output(command, success_statuses=success_statuses)
         if status not in success_statuses:
             raise RuntimeError(f"Could not run {command}")
+        m = NO_SUCH_PYTHON_REGEX.search(output)
+        if m is not None:
+            raise PythonNotFound(f"Could not locate Python {python} ; {m.group(0)}")
         lines = output.splitlines(keepends=False)
         for line in lines:
             logger.debug("line = %s", line)
