@@ -1,3 +1,6 @@
+"""Utility functions.
+"""
+
 import os
 import subprocess
 import sys
@@ -6,7 +9,7 @@ from distutils.util import strtobool
 from os.path import expandvars, expanduser
 from pathlib import Path
 from shutil import which
-
+from typing import List, Tuple
 
 logger = logging.getLogger(__name__)
 
@@ -29,6 +32,10 @@ def sub_shell_command(command, suppress_setup_output=True):
     logger.debug("preferred_shell_name from $SHELL = %r", preferred_shell_name)
     shell_name = expandvars(os.environ.get("VENV_MANAGEMENT_SHELL", preferred_shell_name))
     logger.debug("shell_name = %r", shell_name)
+    if "fish" in shell_name:
+        logger.error("Support for fish not yet added")
+        raise NotImplementedError("Support for fish not yet added")
+        
     shell_filepath = which(shell_name)
     logger.debug("shell_filepath = %r", shell_filepath)
     if shell_filepath is None:
@@ -63,10 +70,18 @@ def sub_shell_command(command, suppress_setup_output=True):
 
 
 def shell_is_interactive():
+    """True if the shell has been set to interactive.
+
+    Control the setting with the VENV_MANAGEMENT_INTERACTIVE_SHELL environment variable by
+    setting it to 'yes' or 'no'.
+
+    Returns:
+        True if the shell is interactive, otherwise False.
+    """
     return strtobool(expandvars(os.environ.get("VENV_MANAGEMENT_INTERACTIVE_SHELL", "no")))
 
 
-def get_status_output(cmd: list[str], success_statuses=None):
+def get_status_output(cmd: List[str], success_statuses=None) -> Tuple[int, str]:
     """    Return (status, output) of executing cmd in a shell.
 
     Args:
@@ -107,7 +122,20 @@ def get_status_output(cmd: list[str], success_statuses=None):
     return status, data
 
 
-def has_interactive_warning(line):
+def has_interactive_warning(line: str):
+    """Determine whether a line of text contains a warning emitted by a shell.
+
+    The shell program itself (e.g. bash) can emit warnings under certain circumstances
+    which clutter output; for example, when running a shell in interactive mode without
+    a connected terminal. This predicate can identify lines of text containing such
+    warnings.
+
+    Args:
+        line: A string which may contain a shell warning.
+
+    Returns:
+        True if the line contains a shell warning, otherwise False.
+    """
     return (
             "cannot set terminal process group" in line
             or "Inappropriate ioctl for device" in line
@@ -115,25 +143,62 @@ def has_interactive_warning(line):
     )
 
 
-def remove_interactive_shell_warnings(stderr):
-    lines = stderr.splitlines(keepends=True)
+def remove_interactive_shell_warnings(lines: str) -> str:
+    """Remove shell warnings from lines of text.
+
+    The shell program itself (e.g. bash) can emit warnings under certain circumstances
+    which clutter output; for example, when running a shell in interactive mode without
+    a connected terminal. This predicate can identify lines of text containing such
+    warnings.
+
+    Args:
+        lines: A string (possibly multiline) which may contain lines which have shell warnings.
+
+    Returns:
+        The argument string without any lines containing matching shell warnings.
+    """
+    lines = lines.splitlines(keepends=True)
     lines = [line for line in lines if not has_interactive_warning(line)]
-    stderr = "".join(lines)
-    return stderr
+    lines = "".join(lines)
+    return lines
 
 
-def compatible_versions(actual_version, expected_version):
+def compatible_versions(actual_version: str, required_version: str) -> bool:
+    """Determine whether two versions are equal.
+
+    Only the dot separated elements in common are taken into account, so
+    actual "3.7.4" compared with "3.7" will return True.
+
+    Args:
+        actual_version: A dot separated version.
+        required_version: A dot separated version.
+
+    Returns:
+        True if the actual_version is compatible with the required_version,
+        otherwise False.
+    """
     return all(
         actual == expected
-        for actual, expected in zip(actual_version.split("."), expected_version.split("."))
+        for actual, expected in zip(actual_version.split("."), required_version.split("."))
     )
 
 
 def parse_package_arg(name, arg):
+    """Make a command-line argument string specifing whether and which verison of a package to install.
+
+    Args:
+        name: The name of the package.
+        arg: True if the package is required, False if the package is not required,
+            or a string containing a version number if a specific version of the package
+            is required.
+
+    Returns:
+        A string which can be used as an argument to the virtualenv command.
+    """
     if arg == True:
         option = ""
     elif arg == False:
         option = f"--no-{name}"
     else:
         option = f"--{name}={arg}"
-    return option
\ No newline at end of file
+    return option
